==> perl-5.13.4.tar.gz: perl-5.13.4/cpan/Unicode-Collate/Collate/Locale/sv.pl <==
+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0111      ; [.1250.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0064 0335 ; [.1250.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0110      ; [.1250.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
0044 0335 ; [.1250.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
00F0      ; [.1250.0022.0002.00F0] # LATIN SMALL LETTER ETH
00D0      ; [.1250.0022.0008.00D0] # LATIN CAPITAL LETTER ETH
00FE      ; [.1433.0020.0003.00FE][.12D3.0020.0003.00FE] # LATIN SMALL LETTER THORN
00DE      ; [.1433.0020.0009.00DE][.12D3.0020.0009.00DE] # LATIN CAPITAL LETTER THORN
0077      ; [.147B.0020.0003.0077] # LATIN SMALL LETTER W
0057      ; [.147B.0020.0009.0057] # LATIN CAPITAL LETTER W
00FC      ; [.149C.0021.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.149C.0021.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.149C.0021.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.149C.0021.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0171      ; [.149C.0022.0002.0171] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0075 030B ; [.149C.0022.0002.0171] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0170      ; [.149C.0022.0008.0170] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
0055 030B ; [.149C.0022.0008.0170] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
00E5      ; [.14AE.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
0061 030A ; [.14AE.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
00C5      ; [.14AE.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
0041 030A ; [.14AE.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
212B      ; [.14AE.0020.0008.00C5] # ANGSTROM SIGN
01FB      ; [.14AE.0020.0002.00E5][.0000.0032.0002.0301] # LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01FA      ; [.14AE.0020.0008.00C5][.0000.0032.0002.0301] # LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
00E4      ; [.14AF.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.14AF.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.14AF.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.14AF.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
00E6      ; [.14AF.0021.0002.00E6] # LATIN SMALL LETTER AE
00C6      ; [.14AF.0021.0008.00C6] # LATIN CAPITAL LETTER AE
1D2D      ; [.14AF.0021.0014.1D2D] # MODIFIER LETTER CAPITAL AE
01FD      ; [.14AF.0021.0002.00E6][.0000.0032.0002.0301] # LATIN SMALL LETTER AE WITH ACUTE
01FC      ; [.14AF.0021.0008.00C6][.0000.0032.0002.0301] # LATIN CAPITAL LETTER AE WITH ACUTE
01E3      ; [.14AF.0021.0002.00E6][.0000.005B.0002.0304] # LATIN SMALL LETTER AE WITH MACRON
01E2      ; [.14AF.0021.0008.00C6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER AE WITH MACRON
0119      ; [.14AF.0022.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0065 0328 ; [.14AF.0022.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0118      ; [.14AF.0022.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
0045 0328 ; [.14AF.0022.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
00F6      ; [.14B0.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.14B0.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.14B0.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.14B0.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
00F8      ; [.14B0.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
006F 0338 ; [.14B0.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
00D8      ; [.14B0.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
004F 0338 ; [.14B0.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
01FF      ; [.14B0.0021.0002.00F8][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH STROKE AND ACUTE
01FE      ; [.14B0.0021.0008.00D8][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
0151      ; [.14B0.0022.0002.0151] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
006F 030B ; [.14B0.0022.0002.0151] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
0150      ; [.14B0.0022.0008.0150] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
004F 030B ; [.14B0.0022.0008.0150] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
0153      ; [.14B0.0023.0002.0153] # LATIN SMALL LIGATURE OE
0152      ; [.14B0.0023.0008.0152] # LATIN CAPITAL LIGATURE OE
00F4      ; [.14B0.0024.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
006F 0302 ; [.14B0.0024.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
00D4      ; [.14B0.0024.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
004F 0302 ; [.14B0.0024.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
ENTRY
};

==> perl-5.13.5.tar.gz: perl-5.13.5/cpan/Unicode-Collate/Collate/Locale/sv.pl <==
+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0111      ; [.1250.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0064 0335 ; [.1250.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0110      ; [.1250.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
0044 0335 ; [.1250.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
00F0      ; [.1250.0022.0002.00F0] # LATIN SMALL LETTER ETH
00D0      ; [.1250.0022.0008.00D0] # LATIN CAPITAL LETTER ETH
00FE      ; [.1433.0020.0003.00FE][.12D3.0020.0003.00FE] # LATIN SMALL LETTER THORN
00DE      ; [.1433.0020.0009.00DE][.12D3.0020.0009.00DE] # LATIN CAPITAL LETTER THORN
0077      ; [.147B.0020.0003.0077] # LATIN SMALL LETTER W
0057      ; [.147B.0020.0009.0057] # LATIN CAPITAL LETTER W
00FC      ; [.149C.0021.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.149C.0021.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.149C.0021.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.149C.0021.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
01DC      ; [.149C.0021.0002.00FC][.0000.0035.0002.0300] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.149C.0021.0008.00DC][.0000.0035.0002.0300] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01D8      ; [.149C.0021.0002.00FC][.0000.0032.0002.0301] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.149C.0021.0008.00DC][.0000.0032.0002.0301] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D6      ; [.149C.0021.0002.00FC][.0000.005B.0002.0304] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.149C.0021.0008.00DC][.0000.005B.0002.0304] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01DA      ; [.149C.0021.0002.00FC][.0000.0041.0002.030C] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.149C.0021.0008.00DC][.0000.0041.0002.030C] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
0171      ; [.149C.0022.0002.0171] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0075 030B ; [.149C.0022.0002.0171] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0170      ; [.149C.0022.0008.0170] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
0055 030B ; [.149C.0022.0008.0170] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
00E5      ; [.14AE.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
0061 030A ; [.14AE.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
00C5      ; [.14AE.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
0041 030A ; [.14AE.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
212B      ; [.14AE.0020.0008.00C5] # ANGSTROM SIGN
01FB      ; [.14AE.0020.0002.00E5][.0000.0032.0002.0301] # LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01FA      ; [.14AE.0020.0008.00C5][.0000.0032.0002.0301] # LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
00E4      ; [.14AF.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.14AF.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.14AF.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.14AF.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.14AF.0020.0002.00E4][.0000.005B.0002.0304] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.14AF.0020.0008.00C4][.0000.005B.0002.0304] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00E6      ; [.14AF.0021.0002.00E6] # LATIN SMALL LETTER AE
00C6      ; [.14AF.0021.0008.00C6] # LATIN CAPITAL LETTER AE
1D2D      ; [.14AF.0021.0014.1D2D] # MODIFIER LETTER CAPITAL AE
01FD      ; [.14AF.0021.0002.00E6][.0000.0032.0002.0301] # LATIN SMALL LETTER AE WITH ACUTE
01FC      ; [.14AF.0021.0008.00C6][.0000.0032.0002.0301] # LATIN CAPITAL LETTER AE WITH ACUTE
01E3      ; [.14AF.0021.0002.00E6][.0000.005B.0002.0304] # LATIN SMALL LETTER AE WITH MACRON
01E2      ; [.14AF.0021.0008.00C6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER AE WITH MACRON
0119      ; [.14AF.0022.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0065 0328 ; [.14AF.0022.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0118      ; [.14AF.0022.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
0045 0328 ; [.14AF.0022.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
00F6      ; [.14B0.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.14B0.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.14B0.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.14B0.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.14B0.0020.0002.00F6][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.14B0.0020.0008.00D6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
00F8      ; [.14B0.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
006F 0338 ; [.14B0.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
00D8      ; [.14B0.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
004F 0338 ; [.14B0.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
01FF      ; [.14B0.0021.0002.00F8][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH STROKE AND ACUTE
01FE      ; [.14B0.0021.0008.00D8][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
0151      ; [.14B0.0022.0002.0151] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
006F 030B ; [.14B0.0022.0002.0151] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
0150      ; [.14B0.0022.0008.0150] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
004F 030B ; [.14B0.0022.0008.0150] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
0153      ; [.14B0.0023.0002.0153] # LATIN SMALL LIGATURE OE
0152      ; [.14B0.0023.0008.0152] # LATIN CAPITAL LIGATURE OE
00F4      ; [.14B0.0024.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
006F 0302 ; [.14B0.0024.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
00D4      ; [.14B0.0024.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
004F 0302 ; [.14B0.0024.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
ENTRY
};
